export const SHOW_DELETE_USER_MODAL = 'SHOW_DELETE_USER_MODAL';
export const HIDE_DELETE_USER_MODAL = 'HIDE_DELETE_USER_MODAL';
export const SHOW_ALL_USERS = 'SHOW_ALL_USERS';
export const ALL_USERS_ERROR = 'ALL_USERS_ERROR';
export const CREATE_NEW_USER_SUCCESS = 'CREATE_NEW_USER_SUCCESS';
export const CREATE_NEW_USER_ERROR = 'CREATE_NEW_USER_ERROR';

//Pending, Success, Error Actions


export function getAllUsersAction(users) {
    console.log("GetAllAction Action")
    return {
        type: SHOW_ALL_USERS,
        userList: users
    }
}

export function getAllUsersErrorAction(error) {
    console.log("Error Action")
    return {
        type: ALL_USERS_ERROR,
        error: error
    }
}

export function getShowDeleteUserModalAction() {
    return {
        type: SHOW_DELETE_USER_MODAL
    }
}

export function getHideDeleteUserModalAction() {
    return {
        type: HIDE_DELETE_USER_MODAL
    }
}


export function getCreateNewUserSuccessAction(userData) {
    console.log("GetCreateNewUserSuccessAction")
    return {
        type: CREATE_NEW_USER_SUCCESS,
        newUserData: userData
    }
}

export function getCreateNewUserErrorAction(error) {
    console.log("GetCreateNewUserErrorAction")
    return {
        type: CREATE_NEW_USER_ERROR,
        error: error
    }
}



//Frontend Connections

export function displayUsers(token) {
    console.log("displaying users")

    return dispatch => {
        dispatch(getAllUsersAction());
        getAllUsers(token)
            .then(users => {
                console.log(users)
                const action = getAllUsersAction(users)
                dispatch(action);
            },
                error => {
                    dispatch(getAllUsersErrorAction(error));
                }
            )
            .catch(error => {
                dispatch(getAllUsersErrorAction(error))
            })
    }
}


export function passNewUser(userData, token) {
    console.log("passing new user")

    return dispatch => {
        dispatch(getCreateNewUserSuccessAction());
        createNewUser(userData, token)
            .then(newUser => {
                console.log(newUser)
                const action = getCreateNewUserSuccessAction(newUser)
                dispatch(action);
            },
                error => {
                    dispatch(getCreateNewUserErrorAction(error));
                }
            )
            .catch(error => {
                dispatch(getCreateNewUserErrorAction(error))
            })
    }

}




//Backend Callings

export function getAllUsers(token) {
    console.log("get all users")
    console.log(token)

    const requestOptions = {
        method: 'GET',
        headers: { 'Authorization': token }
    };

    return fetch('https://localhost/api/users', requestOptions)
        .then(response => {
            return response.json().then(body => {
                if (response.status === 200) {
                    console.log(body)
                    return body
                }
            })
        })
}


export function createNewUser(userData, token) {
    console.log("create new user")
    console.log(userData)

    const requestOptions = {
        method: 'POST',
        headers: {
            'Authorization': token,
            'Content-Type': 'application/json'
        },
        body: JSON.stringify(userData)
    }

    return fetch('https://localhost/api/users', requestOptions)
        .then(response => {
            return response.json().then(body => {
                if (response.status === 200) {
                    console.log(body)
                    return body
                }
            })
        })
}

// json.stringify({userID, passsww})
